/* Copyright (c) 1996 University of Utah.  All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software and
 * its documentation for NON-COMMERCIAL purposes and without fee is
 * hereby granted provided that this copyright notice appears in all
 * copies.
 *
 * See http://www.cs.utah.edu/~hamlet for more educational resources.
 *
 * The University of Utah MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT
 * THE SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR
 * NON-INFRINGEMENT. The University of Utah SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

package BlockStacker;

import java.awt.*;


//************************************************************************
// Block class
//************************************************************************

class Block {
    
    //----------------------------------------------------------
    // Instance variables
    //----------------------------------------------------------

    public int offset;     // offset from support
    public int oldOffset;
    public Color color;

    
    //----------------------------------------------------------
    // Constructor
    //----------------------------------------------------------
    
    Block () {
	offset = 0;
	color = WorkArea.blockOKColor;
    }

    
    //----------------------------------------------------------
    // Draw the block from scratch, given x and y coordinates of UL corner
    //----------------------------------------------------------

    public void draw (Graphics g, int x, int y, int width, int height) {

	// Outline the block
	
	g.setColor(color);
	g.fillRect(x, y, width-1, height-1);
	
	g.setColor(WorkArea.borderColor);
	g.drawRect(x, y, width-1, height-1);


	// Display the number of pixels of overhang

	String label = Integer.toString(offset);
	FontMetrics fm = g.getFontMetrics();
	int labelWidth = fm.stringWidth(label);
	int baselineOffset = fm.getAscent() + fm.getLeading();
	g.drawString(label, x+(width-labelWidth)/2, y+baselineOffset);

    }

    
    // Redo the color and label of the block

    public void recolor (Graphics g, int x, int y, int width, int height) {
	g.setColor(color);
	g.fillRect(x+1, y+1, width-2, height-2);
	g.setColor(WorkArea.borderColor);
	String label = Integer.toString(offset);
	FontMetrics fm = g.getFontMetrics();
	int labelWidth = fm.stringWidth(label);
	int baselineOffset = fm.getAscent() + fm.getLeading();
	g.drawString(label, x+(width-labelWidth)/2, y+baselineOffset);
    }


    //----------------------------------------------------------
    // Erase the block
    //----------------------------------------------------------
    
    public void erase (Graphics g, int x, int y, int width, int height,
		       Color background) {

	g.setColor(background);
	g.fillRect(x, y, width, height);

    }

}
